export default {
  server: {
    host: '127.0.0.1',
    port: 5000,
  },
  /*
   ** Nuxt rendering mode
   ** See https://nuxtjs.org/api/configuration-mode
   */
  mode: 'spa',
  /*
   ** Nuxt target
   ** See https://nuxtjs.org/api/configuration-target
   */
  target: 'static',
  /*
   ** Headers of the page
   ** See https://nuxtjs.org/api/configuration-head
   */
  head: {
    title: process.env.npm_package_name || '',
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      {
        hid: 'description',
        name: 'description',
        content: process.env.npm_package_description || '',
      },
    ],
    link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },{ rel: 'stylesheet', href: 'https://fonts.googleapis.com/css?family=Roboto' }],
  },
  /*
   ** Global CSS
   */
  css: ['element-ui/lib/theme-chalk/index.css','postcss/docs/api/assets/styles.min.css'],
  /*
   ** Plugins to load before mounting the App
   ** https://nuxtjs.org/guide/plugins
   */
  plugins: ['@/plugins/element-ui','@/plugins/vue-cookies','@/plugins/global','@/plugins/moment','@/plugins/contextmenu','@/plugins/uuid'],
  /*
   ** Auto import components
   ** See https://nuxtjs.org/api/configuration-components
   */
  components: true,
  /*
   ** Nuxt.js dev-modules
   */
  buildModules: [
    '@nuxt/typescript-build',
    // Doc: https://github.com/nuxt-community/stylelint-module
    '@nuxtjs/stylelint-module',
  ],
  /*
   ** Nuxt.js modules
   */
  modules: [
    // Doc: https://axios.nuxtjs.org/usage
    '@nuxtjs/axios',
    '@nuxtjs/pwa',
    // Doc: https://github.com/nuxt/content
    '@nuxt/content',
    'nuxt-i18n'
  ],
  /*
   ** Axios module configuration
   ** See https://axios.nuxtjs.org/options
   */
  axios: {},
  /*
   ** Content module configuration
   ** See https://content.nuxtjs.org/configuration
   */
  content: {},
  /*
   ** Build configuration
   ** See https://nuxtjs.org/api/configuration-build/
   */
  build: {
    transpile: [/^element-ui/],
  },
  i18n: {
    locales: ['zhCN', 'en'],
    defaultLocale: 'zhCN',
    vueI18n: {
      fallbackLocale: 'zhCN',
      messages: {
        "zhCN": {
          "account": {
            "form": {
              "confirmPwd": "确认密码",
              "password": "密码",
              "tip": {
                "login_fail": "登陆失败，账号或密码错误",
                "login_ok": "登录成功",
                "register_fail": "注册失败",
                "register_ok": "注册成功",
                "tow_diff": "两次输入密码不一致!",
                "user_exit": "用户{name}已存在",
                "valid_account": "帐号密码正确"
              },
              "user": "帐号"
            },
            "login": "登录",
            "register": "注册"
          },
          "action": "操作",
          "app_name": "云笔记",
          "button": {
            "add": "添加",
            "cancel": "取消",
            "catalog": "目录",
            "del": "删除",
            "edit": "编辑",
            "jump_note": "定位笔记",
            "ok": "确定",
            "query": "查询",
            "rating": "提交评分",
            "submit": "提交"
          },
          "center": {
            "collect": {
              "form": {
                "time": "收藏时间",
                "title": "论文标题"
              },
              "name": "我的收藏"
            },
            "myupload": {
              "form": {
                "time": "上传时间",
                "title": "论文标题"
              },
              "name": "我的上传"
            },
            "security": {
              "confirmpwd": "确认新密码",
              "name": "帐号安全",
              "newpwd": "新密码",
              "oldpwd": "原密码",
              "rules": {
                "password": "长度在 {min} 到 {max} 个字符之间"
              },
              "tip": {
                "fail": "密码修改失败",
                "ok": "密码修改成功，请重新登录",
                "same_err": "新密码不能和旧密码一致"
              }
            }
          },
          "choose_lang": "选择语言",
          "document": {
            "doc_list": {
              "year": "（学位年度）"
            },
            "form": {
              "author": "作者",
              "content": "正文内容",
              "end_year": "结束年份",
              "profession": "学科专业",
              "school": "学校",
              "start_year": "开始年份",
              "tag": "标签",
              "title": "标题",
              "tutor": "导师"
            },
            "tip": {
              "doc_empty": "没有匹配到一篇论文",
              "recommend_empty": "暂无论文推荐"
            }
          },
          "en": "英文",
          "error_404": "页面不存在",
          "error_500": "发生严重异常，请联系管理员",
          "form_err": "表单校验失败，请检查表单内容",
          "hide_more_query": "隐藏更多查询",
          "input_confirm": "请确认{keyword}",
          "input_please": "请输入{keyword}",
          "logout": "注销登录",
          "menus": {
            "center": "个人中心",
            "document": "文档",
            "note": "笔记列表",
            "read": "阅读论文",
            "upload": "本地上传论文"
          },
          "more_query": "更多查询",
          "new_recommend": "最新推荐",
          "note": {
            "table": {
              "note_content": "笔记内容",
              "note_title": "笔记标题",
              "original_text": "注释原文",
              "paper_name": "论文标题"
            },
            "tip": {
              "confirm_del": "此操作将永久删除该笔记，是否继续？"
            }
          },
          "read": {
            "contextmenu": {
              "add": "添加笔记",
              "search": "查找"
            },
            "form": {
              "keyword": "关键字"
            },
            "tip": {
              "add_tip": "是否添加该笔记？",
              "add_tip_fail": "笔记添加失败",
              "add_tip_ok": "笔记添加成功",
              "auto_save": "失去焦点自动保存",
              "cancel_collect": "取消收藏",
              "cancel_collect_fail": "取消收藏失败",
              "cancel_collect_ok": "取消收藏成功",
              "click_note_list": "单击卡片定位笔记",
              "collect": "收藏",
              "collect_fail": "收藏失败",
              "collect_ok": "收藏成功",
              "contextmenu_err": "请选中文本进行操作",
              "del_confirm": "确认删除此笔记？",
              "note_zero": "还没有任何笔记，尝试正文选中文本右击添加一个笔记吧！",
              "rating_1": "本文对您的科研工作是否有帮助",
              "rating_2": "本文的内容是否科学严谨",
              "rating_3": "您对本文的推荐程度",
              "rating_ok": "评价成功",
              "search_next": "查找下一个",
              "search_prev": "查找上一个",
              "search_zero": "正文中没有 ‘{keyword}’",
              "update_note_fail": "笔记保存失败",
              "update_note_ok": "笔记保存成功"
            }
          },
          "reading_online": "在线阅读",
          "reset": "重置",
          "select_please": "请选择{keyword}",
          "tip": "提示",
          "unknown_error": "未知错误",
          "upload": {
            "form": {
              "author": "论文作者",
              "content": "正文内容",
              "profession": "学科专业",
              "remove": "确定移除{file}",
              "school": "学校",
              "summary": "摘要",
              "tag": "论文标签",
              "title": "论文标题",
              "type": "论文类型",
              "upload": "点击上传",
              "upload_tip": "只能上传txt、pdf格式的文件",
              "year": "学位年度"
            },
            "tip": {
              "ok": "论文上传成功"
            }
          },
          "upload_please": "请上传{keyword}",
          "user": "帐号",
          "zhCN": "简体中文"
        },
        "en": {
          "account": {
            "form": {
              "confirmPwd": "Confirm password",
              "password": "Password",
              "tip": {
                "login_fail": "Fail to log in. Please check whether your account name and password are correct.",
                "login_ok": "Log in successfully!",
                "register_fail": "Fail to sign up.",
                "register_ok": "Sign up successfully!",
                "tow_diff": "Passwords do not match.",
                "user_exit": "User {name} already exists.",
                "valid_account": "Account name and password valid."
              },
              "user": "Account name"
            },
            "login": "Log in",
            "register": "Sign up"
          },
          "action": "Action",
          "app_name": "cloudnote",
          "button": {
            "add": "Add",
            "cancel": "Cancel",
            "catalog": "Catalog",
            "del": "Delete",
            "edit": "Edit",
            "jump_note": "Locate the note",
            "ok": "Yes",
            "query": "Query",
            "rating": "Rating",
            "submit": "Submit"
          },
          "center": {
            "collect": {
              "form": {
                "time": "Add time",
                "title": "Title of paper"
              },
              "name": "My bookmark"
            },
            "myupload": {
              "form": {
                "time": "Upload time",
                "title": "Title of paper"
              },
              "name": "My upload"
            },
            "security": {
              "confirmpwd": "Confirm new password",
              "name": "Account security",
              "newpwd": "New password",
              "oldpwd": "Original password",
              "rules": {
                "password": "The length is between {min} and {max} characters"
              },
              "tip": {
                "fail": "Fail to change the password",
                "ok": "Change the password successfully! Please log in again.",
                "same_err": "The new password should not be same as the old one"
              }
            }
          },
          "choose_lang": "language",
          "document": {
            "doc_list": {
              "year": "(degree year)"
            },
            "form": {
              "author": "Author",
              "content": "Content",
              "end_year": "End year",
              "profession": "Major",
              "school": "School",
              "start_year": "Start year",
              "tag": "Tag",
              "title": "Title",
              "tutor": "Tutor"
            },
            "tip": {
              "doc_empty": "There is no paper that matches your request",
              "recommend_empty": "No paper recommendation at present"
            }
          },
          "en": "English",
          "error_404": "Page does not exist",
          "error_500": "There is a serious exception, please contact your administrator",
          "form_err": "Form validation failed. Please check the form contents",
          "hide_more_query": "Hide more queries",
          "input_confirm": "Please confirm {keyword}",
          "input_please": "Please input {keyword}",
          "logout": "Log out",
          "menus": {
            "center": "Account center",
            "document": "Paper list",
            "note": "Note list",
            "read": "Paper reading",
            "upload": "Upload paper"
          },
          "more_query": "More queries",
          "new_recommend": "Latest recommendation",
          "note": {
            "table": {
              "note_content": "Note content",
              "note_title": "Note title",
              "original_text": "Content of original paper",
              "paper_name": "Title of original paper"
            },
            "tip": {
              "confirm_del": "This action will delete the note permanently. Do you want to continue?"
            }
          },
          "read": {
            "contextmenu": {
              "add": "Add a note",
              "search": "Find"
            },
            "form": {
              "keyword": "Keyword"
            },
            "tip": {
              "add_tip": "Do you want to add this note?",
              "add_tip_fail": "Fail to add the note.",
              "add_tip_ok": "Add the note successfully",
              "auto_save": "Lost focus and auto save",
              "cancel_collect": "Delete the bookmark",
              "cancel_collect_fail": "Fail to delete the bookmark",
              "cancel_collect_ok": "Delete the bookmark successfully",
              "click_note_list": "Click on the card to locate the note",
              "collect": "Add bookmark",
              "collect_fail": "Fail to add bookmark",
              "collect_ok": "Add bookmark successfully",
              "contextmenu_err": "Please select the text to operate",
              "del_confirm": "Do you want to delete this note?",
              "note_zero": "There are not any notes yet. Try adding a note by right-clicking the selected text in the body.",
              "rating_1": "Is this paper helpful to your scientific research work?",
              "rating_2": "Is the content of this paper scientifically rigorous?",
              "rating_3": "How much do you recommend this paper?",
              "rating_ok": "Rating successfully",
              "search_next": "Find the next",
              "search_prev": "Find the last",
              "search_zero": "There is no ‘{keyword}’ in the body",
              "update_note_fail": "Fail to save the note",
              "update_note_ok": "Save the note successfully"
            }
          },
          "reading_online": "Online reading",
          "reset": "Reset",
          "select_please": "Please select {keyword}",
          "tip": "Tip",
          "unknown_error": "Unknown error",
          "upload": {
            "form": {
              "author": "Author",
              "content": "Content",
              "profession": "Major",
              "remove": "Confirm to remove {file}",
              "school": "School",
              "summary": "Summary",
              "tag": "Tag",
              "title": "Title",
              "type": "Type",
              "upload": "Click to upload",
              "upload_tip": "You can only upload the '.txt' format files.",
              "year": "Degree year"
            },
            "tip": {
              "ok": "Upload paper successfully"
            }
          },
          "upload_please": "Please upload {keyword}",
          "user": "Account name",
          "zhCN": "Simplified Chinese"
        }
      }
    }
  }
}
